@@ -6,7 +6,7 @@ from manifestoo_core.addons_set import AddonsSet
 from manifestoo_core.manifest import Manifest
 
 
-def populate_addons_dir(addons_dir: Path, addons: Dict[str, Dict[str, Any]]):
+def populate_addons_dir(addons_dir: Path, addons: Dict[str, Dict[str, Any]]) -> None:
     if not addons_dir.is_dir():
         addons_dir.mkdir()
     for addon_name, manifest in addons.items():
@@ -17,16 +17,10 @@ def populate_addons_dir(addons_dir: Path, addons: Dict[str, Dict[str, Any]]):
         manifest_path.write_text(repr(manifest))
 
 
-def mock_manifest(
-    manifest_dict: Dict[str, Any], addon_name: str = "fake-addon"
-) -> Manifest:
-    manifest_path = Path("/tmp/fake-addons-dir") / addon_name / "__manifest__.py"
-    return Manifest(manifest_path, manifest_dict)
-
-
 def mock_addons_set(addons: Dict[str, Dict[str, Any]]) -> AddonsSet:
     addons_set = AddonsSet()
     for addon_name, manifest_dict in addons.items():
-        manifest = mock_manifest(manifest_dict, addon_name)
-        addons_set[addon_name] = Addon(manifest)
+        manifest = Manifest.from_dict(manifest_dict)
+        manifest_path = Path("/tmp/fake-addons-dir") / addon_name / "__manifest__.py"
+        addons_set[addon_name] = Addon(manifest, manifest_path)
     return addons_set
